==> google-cloud-sdk-541.0.0.tgz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/aiplatform_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .api_auth import (
    ApiAuth,
)
from .auth import (
    AuthConfig,
    AuthType,
    HttpElementLocation,
)
from .content import (
    Blob,
    Candidate,
    Citation,
    CitationMetadata,
    Content,
    FileData,
    GenerationConfig,
    GroundingChunk,
    GroundingMetadata,
    GroundingSupport,
    LogprobsResult,
    ModalityTokenCount,
    ModelArmorConfig,
    Part,
    PrebuiltVoiceConfig,
    ProactivityConfig,
    RetrievalMetadata,
    SafetyRating,
    SafetySetting,
    SearchEntryPoint,
    Segment,
    SpeechConfig,
    UrlContextMetadata,
    UrlMetadata,
    VideoMetadata,
    VoiceConfig,
    HarmCategory,
    Modality,
)
from .encryption_spec import (
    EncryptionSpec,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    Examples,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    Presets,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    DirectUploadSource,
    GcsDestination,
    GcsSource,
    GoogleDriveSource,
    JiraSource,
    SharePointSources,
    SlackSource,
    TFRecordDestination,
)
from .openapi import (
    Schema,
    Type,
)
from .prediction_service import (
    ChatCompletionsRequest,
    CountTokensRequest,
    CountTokensResponse,
    DirectPredictRequest,
    DirectPredictResponse,
    DirectRawPredictRequest,
    DirectRawPredictResponse,
    ExplainRequest,
    ExplainResponse,
    FetchPredictOperationRequest,
    GenerateContentRequest,
    GenerateContentResponse,
    GenerateVideoResponse,
    PredictLongRunningMetadata,
    PredictLongRunningRequest,
    PredictLongRunningResponse,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
    StreamDirectPredictRequest,
    StreamDirectPredictResponse,
    StreamDirectRawPredictRequest,
    StreamDirectRawPredictResponse,
    StreamingPredictRequest,
    StreamingPredictResponse,
    StreamingRawPredictRequest,
    StreamingRawPredictResponse,
    StreamRawPredictRequest,
)
from .tool import (
    CodeExecutionResult,
    DynamicRetrievalConfig,
    EnterpriseWebSearch,
    ExecutableCode,
    ExternalApi,
    FunctionCall,
    FunctionCallingConfig,
    FunctionDeclaration,
    FunctionResponse,
    GoogleMaps,
    GoogleSearchRetrieval,
    RagRetrievalConfig,
    Retrieval,
    RetrievalConfig,
    Tool,
    ToolConfig,
    ToolUseExample,
    UrlContext,
    VertexAISearch,
    VertexRagStore,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
    Tensor,
)
from .vertex_rag_data import (
    CorpusStatus,
    FileStatus,
    ImportRagFilesConfig,
    RagChunk,
    RagCorpus,
    RagEmbeddingModelConfig,
    RagEngineConfig,
    RagFile,
    RagFileChunkingConfig,
    RagFileMetadataConfig,
    RagFileParsingConfig,
    RagFileTransformationConfig,
    RagManagedDbConfig,
    RagVectorDbConfig,
    UploadRagFileConfig,
    VertexAiSearchConfig,
)

__all__ = (
    'ApiAuth',
    'AuthConfig',
    'AuthType',
    'HttpElementLocation',
    'Blob',
    'Candidate',
    'Citation',
    'CitationMetadata',
    'Content',
    'FileData',
    'GenerationConfig',
    'GroundingChunk',
    'GroundingMetadata',
    'GroundingSupport',
    'LogprobsResult',
    'ModalityTokenCount',
    'ModelArmorConfig',
    'Part',
    'PrebuiltVoiceConfig',
    'ProactivityConfig',
    'RetrievalMetadata',
    'SafetyRating',
    'SafetySetting',
    'SearchEntryPoint',
    'Segment',
    'SpeechConfig',
    'UrlContextMetadata',
    'UrlMetadata',
    'VideoMetadata',
    'VoiceConfig',
    'HarmCategory',
    'Modality',
    'EncryptionSpec',
    'Attribution',
    'BlurBaselineConfig',
    'Examples',
    'ExamplesOverride',
    'ExamplesRestrictionsNamespace',
    'Explanation',
    'ExplanationMetadataOverride',
    'ExplanationParameters',
    'ExplanationSpec',
    'ExplanationSpecOverride',
    'FeatureNoiseSigma',
    'IntegratedGradientsAttribution',
    'ModelExplanation',
    'Neighbor',
    'Presets',
    'SampledShapleyAttribution',
    'SmoothGradConfig',
    'XraiAttribution',
    'ExplanationMetadata',
    'AvroSource',
    'BigQueryDestination',
    'BigQuerySource',
    'ContainerRegistryDestination',
    'CsvDestination',
    'CsvSource',
    'DirectUploadSource',
    'GcsDestination',
    'GcsSource',
    'GoogleDriveSource',
    'JiraSource',
    'SharePointSources',
    'SlackSource',
    'TFRecordDestination',
    'Schema',
    'Type',
    'ChatCompletionsRequest',
    'CountTokensRequest',
    'CountTokensResponse',
    'DirectPredictRequest',
    'DirectPredictResponse',
    'DirectRawPredictRequest',
    'DirectRawPredictResponse',
    'ExplainRequest',
    'ExplainResponse',
    'FetchPredictOperationRequest',
    'GenerateContentRequest',
    'GenerateContentResponse',
    'GenerateVideoResponse',
    'PredictLongRunningMetadata',
    'PredictLongRunningRequest',
    'PredictLongRunningResponse',
    'PredictRequest',
    'PredictResponse',
    'RawPredictRequest',
    'StreamDirectPredictRequest',
    'StreamDirectPredictResponse',
    'StreamDirectRawPredictRequest',
    'StreamDirectRawPredictResponse',
    'StreamingPredictRequest',
    'StreamingPredictResponse',
    'StreamingRawPredictRequest',
    'StreamingRawPredictResponse',
    'StreamRawPredictRequest',
    'CodeExecutionResult',
    'DynamicRetrievalConfig',
    'EnterpriseWebSearch',
    'ExecutableCode',
    'ExternalApi',
    'FunctionCall',
    'FunctionCallingConfig',
    'FunctionDeclaration',
    'FunctionResponse',
    'GoogleMaps',
    'GoogleSearchRetrieval',
    'RagRetrievalConfig',
    'Retrieval',
    'RetrievalConfig',
    'Tool',
    'ToolConfig',
    'ToolUseExample',
    'UrlContext',
    'VertexAISearch',
    'VertexRagStore',
    'BoolArray',
    'DoubleArray',
    'Int64Array',
    'StringArray',
    'Tensor',
    'CorpusStatus',
    'FileStatus',
    'ImportRagFilesConfig',
    'RagChunk',
    'RagCorpus',
    'RagEmbeddingModelConfig',
    'RagEngineConfig',
    'RagFile',
    'RagFileChunkingConfig',
    'RagFileMetadataConfig',
    'RagFileParsingConfig',
    'RagFileTransformationConfig',
    'RagManagedDbConfig',
    'RagVectorDbConfig',
    'UploadRagFileConfig',
    'VertexAiSearchConfig',
)

==> google-cloud-sdk-548.0.0.tgz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/aiplatform_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .api_auth import (
    ApiAuth,
)
from .auth import (
    AuthConfig,
    AuthType,
    HttpElementLocation,
)
from .content import (
    Blob,
    Candidate,
    Citation,
    CitationMetadata,
    Content,
    FileData,
    GenerationConfig,
    GroundingChunk,
    GroundingMetadata,
    GroundingSupport,
    ImageConfig,
    LogprobsResult,
    ModalityTokenCount,
    ModelArmorConfig,
    MultiSpeakerVoiceConfig,
    Part,
    PrebuiltVoiceConfig,
    ProactivityConfig,
    RetrievalMetadata,
    SafetyRating,
    SafetySetting,
    SearchEntryPoint,
    Segment,
    SpeakerVoiceConfig,
    SpeechConfig,
    UrlContextMetadata,
    UrlMetadata,
    VideoMetadata,
    VoiceConfig,
    HarmCategory,
    Modality,
)
from .encryption_spec import (
    EncryptionSpec,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    Examples,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    Presets,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    DirectUploadSource,
    GcsDestination,
    GcsSource,
    GoogleDriveSource,
    JiraSource,
    SharePointSources,
    SlackSource,
    TFRecordDestination,
)
from .openapi import (
    Schema,
    Type,
)
from .prediction_service import (
    ChatCompletionsRequest,
    CountTokensRequest,
    CountTokensResponse,
    DirectPredictRequest,
    DirectPredictResponse,
    DirectRawPredictRequest,
    DirectRawPredictResponse,
    EmbedContentRequest,
    EmbedContentResponse,
    ExplainRequest,
    ExplainResponse,
    FetchPredictOperationRequest,
    GenerateContentRequest,
    GenerateContentResponse,
    GenerateVideoResponse,
    InvokeRequest,
    PredictLongRunningMetadata,
    PredictLongRunningRequest,
    PredictLongRunningResponse,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
    StreamDirectPredictRequest,
    StreamDirectPredictResponse,
    StreamDirectRawPredictRequest,
    StreamDirectRawPredictResponse,
    StreamingPredictRequest,
    StreamingPredictResponse,
    StreamingRawPredictRequest,
    StreamingRawPredictResponse,
    StreamRawPredictRequest,
)
from .tool import (
    CodeExecutionResult,
    DynamicRetrievalConfig,
    EnterpriseWebSearch,
    ExecutableCode,
    ExternalApi,
    FunctionCall,
    FunctionCallingConfig,
    FunctionDeclaration,
    FunctionResponse,
    FunctionResponseBlob,
    FunctionResponseFileData,
    FunctionResponsePart,
    GoogleMaps,
    GoogleSearchRetrieval,
    RagRetrievalConfig,
    Retrieval,
    RetrievalConfig,
    Tool,
    ToolConfig,
    ToolUseExample,
    UrlContext,
    VertexAISearch,
    VertexRagStore,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
    Tensor,
)
from .usage_metadata import (
    UsageMetadata,
)
from .vertex_rag_data import (
    CorpusStatus,
    FileStatus,
    ImportRagFilesConfig,
    RagChunk,
    RagCorpus,
    RagEmbeddingModelConfig,
    RagEngineConfig,
    RagFile,
    RagFileChunkingConfig,
    RagFileMetadataConfig,
    RagFileParsingConfig,
    RagFileTransformationConfig,
    RagManagedDbConfig,
    RagVectorDbConfig,
    UploadRagFileConfig,
    VertexAiSearchConfig,
)

__all__ = (
    'ApiAuth',
    'AuthConfig',
    'AuthType',
    'HttpElementLocation',
    'Blob',
    'Candidate',
    'Citation',
    'CitationMetadata',
    'Content',
    'FileData',
    'GenerationConfig',
    'GroundingChunk',
    'GroundingMetadata',
    'GroundingSupport',
    'ImageConfig',
    'LogprobsResult',
    'ModalityTokenCount',
    'ModelArmorConfig',
    'MultiSpeakerVoiceConfig',
    'Part',
    'PrebuiltVoiceConfig',
    'ProactivityConfig',
    'RetrievalMetadata',
    'SafetyRating',
    'SafetySetting',
    'SearchEntryPoint',
    'Segment',
    'SpeakerVoiceConfig',
    'SpeechConfig',
    'UrlContextMetadata',
    'UrlMetadata',
    'VideoMetadata',
    'VoiceConfig',
    'HarmCategory',
    'Modality',
    'EncryptionSpec',
    'Attribution',
    'BlurBaselineConfig',
    'Examples',
    'ExamplesOverride',
    'ExamplesRestrictionsNamespace',
    'Explanation',
    'ExplanationMetadataOverride',
    'ExplanationParameters',
    'ExplanationSpec',
    'ExplanationSpecOverride',
    'FeatureNoiseSigma',
    'IntegratedGradientsAttribution',
    'ModelExplanation',
    'Neighbor',
    'Presets',
    'SampledShapleyAttribution',
    'SmoothGradConfig',
    'XraiAttribution',
    'ExplanationMetadata',
    'AvroSource',
    'BigQueryDestination',
    'BigQuerySource',
    'ContainerRegistryDestination',
    'CsvDestination',
    'CsvSource',
    'DirectUploadSource',
    'GcsDestination',
    'GcsSource',
    'GoogleDriveSource',
    'JiraSource',
    'SharePointSources',
    'SlackSource',
    'TFRecordDestination',
    'Schema',
    'Type',
    'ChatCompletionsRequest',
    'CountTokensRequest',
    'CountTokensResponse',
    'DirectPredictRequest',
    'DirectPredictResponse',
    'DirectRawPredictRequest',
    'DirectRawPredictResponse',
    'EmbedContentRequest',
    'EmbedContentResponse',
    'ExplainRequest',
    'ExplainResponse',
    'FetchPredictOperationRequest',
    'GenerateContentRequest',
    'GenerateContentResponse',
    'GenerateVideoResponse',
    'InvokeRequest',
    'PredictLongRunningMetadata',
    'PredictLongRunningRequest',
    'PredictLongRunningResponse',
    'PredictRequest',
    'PredictResponse',
    'RawPredictRequest',
    'StreamDirectPredictRequest',
    'StreamDirectPredictResponse',
    'StreamDirectRawPredictRequest',
    'StreamDirectRawPredictResponse',
    'StreamingPredictRequest',
    'StreamingPredictResponse',
    'StreamingRawPredictRequest',
    'StreamingRawPredictResponse',
    'StreamRawPredictRequest',
    'CodeExecutionResult',
    'DynamicRetrievalConfig',
    'EnterpriseWebSearch',
    'ExecutableCode',
    'ExternalApi',
    'FunctionCall',
    'FunctionCallingConfig',
    'FunctionDeclaration',
    'FunctionResponse',
    'FunctionResponseBlob',
    'FunctionResponseFileData',
    'FunctionResponsePart',
    'GoogleMaps',
    'GoogleSearchRetrieval',
    'RagRetrievalConfig',
    'Retrieval',
    'RetrievalConfig',
    'Tool',
    'ToolConfig',
    'ToolUseExample',
    'UrlContext',
    'VertexAISearch',
    'VertexRagStore',
    'BoolArray',
    'DoubleArray',
    'Int64Array',
    'StringArray',
    'Tensor',
    'UsageMetadata',
    'CorpusStatus',
    'FileStatus',
    'ImportRagFilesConfig',
    'RagChunk',
    'RagCorpus',
    'RagEmbeddingModelConfig',
    'RagEngineConfig',
    'RagFile',
    'RagFileChunkingConfig',
    'RagFileMetadataConfig',
    'RagFileParsingConfig',
    'RagFileTransformationConfig',
    'RagManagedDbConfig',
    'RagVectorDbConfig',
    'UploadRagFileConfig',
    'VertexAiSearchConfig',
)
